import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Manage a Site Reliability Guardian in Dynatrace
 *
 * @schema CfnSiteReliabilityGuardianProps
 */
export interface CfnSiteReliabilityGuardianProps {
    /**
     * The name of the Site Reliability Guardian.
     *
     * @schema CfnSiteReliabilityGuardianProps#Name
     */
    readonly name: string;
    /**
     * The description of the Site Reliability Guardian.
     *
     * @schema CfnSiteReliabilityGuardianProps#Description
     */
    readonly description?: string;
    /**
     * Define key/value pairs that further describe this guardian.
     *
     * @schema CfnSiteReliabilityGuardianProps#Tags
     */
    readonly tags: string[];
    /**
     * Define variables for dynamically defining DQL queries
     *
     * @schema CfnSiteReliabilityGuardianProps#Variables
     */
    readonly variables: Variable[];
    /**
     * Objectives are means for measuring the performance, availability, capacity, and security of your services.
     *
     * @schema CfnSiteReliabilityGuardianProps#Objectives
     */
    readonly objectives: Objective[];
}
/**
 * Converts an object of type 'CfnSiteReliabilityGuardianProps' to JSON representation.
 */
export declare function toJson_CfnSiteReliabilityGuardianProps(obj: CfnSiteReliabilityGuardianProps | undefined): Record<string, any> | undefined;
/**
 * @schema Variable
 */
export interface Variable {
    /**
     * @schema Variable#Name
     */
    readonly name: string;
    /**
     * @schema Variable#Definition
     */
    readonly definition: string;
}
/**
 * Converts an object of type 'Variable' to JSON representation.
 */
export declare function toJson_Variable(obj: Variable | undefined): Record<string, any> | undefined;
/**
 * @schema Objective
 */
export interface Objective {
    /**
     * @schema Objective#Name
     */
    readonly name: string;
    /**
     * @schema Objective#Description
     */
    readonly description?: string;
    /**
     * @schema Objective#ObjectiveType
     */
    readonly objectiveType: ObjectiveObjectiveType;
    /**
     * @schema Objective#ComparisonOperator
     */
    readonly comparisonOperator: ObjectiveComparisonOperator;
    /**
     * @schema Objective#DqlQuery
     */
    readonly dqlQuery?: string;
    /**
     * @schema Objective#Target
     */
    readonly target?: number;
    /**
     * @schema Objective#Warning
     */
    readonly warning?: number;
    /**
     * Please enter the metric key of your desired SLO. SLO metric keys have to start with 'func:slo.'
     *
     * @schema Objective#ReferenceSlo
     */
    readonly referenceSlo?: string;
    /**
     * Auto-adaptive thresholds are a dynamic approach to baselining where the reference value for detecting anomalies changes over time.
     *
     * @schema Objective#AutoAdaptiveThresholdEnabled
     */
    readonly autoAdaptiveThresholdEnabled?: boolean;
}
/**
 * Converts an object of type 'Objective' to JSON representation.
 */
export declare function toJson_Objective(obj: Objective | undefined): Record<string, any> | undefined;
/**
 * @schema ObjectiveObjectiveType
 */
export declare enum ObjectiveObjectiveType {
    /** DQL */
    DQL = "DQL",
    /** REFERENCE_SLO */
    REFERENCE_UNDERSCORE_SLO = "REFERENCE_SLO"
}
/**
 * @schema ObjectiveComparisonOperator
 */
export declare enum ObjectiveComparisonOperator {
    /** GREATER_THAN_OR_EQUAL */
    GREATER_UNDERSCORE_THAN_UNDERSCORE_OR_UNDERSCORE_EQUAL = "GREATER_THAN_OR_EQUAL",
    /** LESS_THAN_OR_EQUAL */
    LESS_UNDERSCORE_THAN_UNDERSCORE_OR_UNDERSCORE_EQUAL = "LESS_THAN_OR_EQUAL"
}
/**
 * A CloudFormation `Dynatrace::Automation::SiteReliabilityGuardian`
 *
 * @cloudformationResource Dynatrace::Automation::SiteReliabilityGuardian
 * @stability external
 * @link https://github.com/aws-ia/cloudformation-dynatrace-resource-providers.git
 */
export declare class CfnSiteReliabilityGuardian extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Dynatrace::Automation::SiteReliabilityGuardian";
    /**
     * Resource props.
     */
    readonly props: CfnSiteReliabilityGuardianProps;
    /**
     * Attribute `Dynatrace::Automation::SiteReliabilityGuardian.ObjectId`
     * @link https://github.com/aws-ia/cloudformation-dynatrace-resource-providers.git
     */
    readonly attrObjectId: string;
    /**
     * Create a new `Dynatrace::Automation::SiteReliabilityGuardian`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnSiteReliabilityGuardianProps);
}
